@@ -7,5 +7,5 @@ var searchData=
   ['rollleftkey_4',['rollLeftKey',['../classvsg_1_1_trackball.html#a89dec9e52839ef9f8f5bea0abb79e2be',1,'vsg::Trackball']]],
   ['rollrightkey_5',['rollRightKey',['../classvsg_1_1_trackball.html#a59477467f42741f40faeeeea52f691ff',1,'vsg::Trackball']]],
   ['rotatebuttonmask_6',['rotateButtonMask',['../classvsg_1_1_trackball.html#a59c885b238c0565d3ed08c1a4916f7ab',1,'vsg::Trackball']]],
-  ['rotations_7',['rotations',['../classvsg_1_1_transform_keyframes.html#a0befdc8256908c49da775b2dcdf6351a',1,'vsg::TransformKeyframes']]]
+  ['rotations_7',['rotations',['../classvsg_1_1_camera_keyframes.html#ab0101d315d55f7439ae2127053811ee4',1,'vsg::CameraKeyframes::rotations'],['../classvsg_1_1_transform_keyframes.html#a0befdc8256908c49da775b2dcdf6351a',1,'vsg::TransformKeyframes::rotations']]]
 ];
